#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_DIVCEIL_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_DIVCEIL_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/divceil.hpp>

#endif
